@@ -27,12 +27,14 @@ import configure
 def delete():
     print "Are you sure (Y/N)?"
     ask = raw_input("> ").lower()
+    data_path = os.path.join(os.getcwd(), "data.csv")
     if ask == 'n' or ask == 'no':
         exit(0)
     else:
-        txt = open(quiz.data_path, 'w')
+        txt = open(data_path, 'w')
         txt.truncate()
         txt.close()
+        print "Erased '%s'." % data_path
 
 def adder(table):
     breakers = "end exit break close leave stop".split()
@@ -82,7 +84,7 @@ def sub_menu_sqlite3(table):
         print "="*72
 def menu_sqlite3(load=None):
     print "Connected to %s" % quiz_sql.path
-    print "="*72,"\n"
+    print "="*72,"\n\n"
     
     if load:
         sub_menu_sqlite3(load)
@@ -98,7 +100,7 @@ def menu_sqlite3(load=None):
             print "5: exit\n" #Works
             
             ask = raw_input("> ").lower()
-            print "="*72
+            #print "="*72
 
             if ask == 'list':
                 for table in quiz_sql.db.index:
@@ -117,6 +119,12 @@ def menu_sqlite3(load=None):
                 print "Deleted %s set." % table
                 
             if ask == '4':
+                print "="*72
+                print "Are you sure? (y\\n)"
+                check = raw_input(">\n")
+                if check.lower() == 'n':
+                    print "="*72
+                    continue
                 quiz_sql.erase_all_sets()
                 
             if ask.lower() == 'exit' or ask == 'end' or ask == '5':
@@ -126,17 +134,12 @@ def menu_sqlite3(load=None):
 def menu_csv():
     while True:
         print "1: Enter quiz mode"
-        print "\tflashcards.quiz.reader()"
-
         print "2: Enter quiz editor"
-        print "\tflashcards.quiz.writer()"
-
         print "3: Erase current quiz"
-        print "\tflashcards.delete()"
         print "4: Exit"
         ask = raw_input("> ").lower()
         
-        #print "="*72,"\n"
+       
         
         if ask == 'end':
             break
@@ -154,7 +157,8 @@ def menu_csv():
             
         if ask == '3' or ask == 'erase current quiz':
             delete()
-
+            
+        print "="*72
 def get_args():
     parser = argparse.ArgumentParser(
         description="Purpose: A command line flashcard interface",
